var app = require('electron').app;
var autoUpdater = require('./utils/autoUpdater');
var createDefaultMenu = require('./views/menu.js');
var electronSettings = require('./electronSettings');
var Environment = require('./utils/Environment');
var handleWindowsStartupEvent = require('./utils/handleWindowsStartupEvent');
var mainWindow = require('./views/mainWindow');
var menuBarIcon = require('./views/menuBarIcon');
var userPreferences = require('./utils/userPreferences');

if (handleWindowsStartupEvent()) {
  return;
}

require('electron-debug')({
  showDevTools: false
});

var checkForUpdates;
if (electronSettings.updateFeedUrl) {
  autoUpdater.setFeedURL(electronSettings.updateFeedUrl + '?version=' + electronSettings.version);
  autoUpdater.checkForUpdates();
  checkForUpdates = function() {
    autoUpdater.checkForUpdates(true /* userTriggered */);
  };
}

app.on('ready', function() {
  var window = mainWindow.initialize();
  createDefaultMenu(app, window, checkForUpdates);
  menuBarIcon.initialize(window);

  userPreferences.mergeRemoteUpdates(window);

  var hotkeyPreference = Environment.isWindows() ? 'appHotkeyWin' : 'appHotkeyMac';

  function updateAppHotkey() {
    var menuBarHotkey = userPreferences.get(hotkeyPreference);
    if (!menuBarIcon.setHotkey(menuBarHotkey)) {
      // TODO(jeff): Error handling.
    }
  }

  // The hot key must be re-registered on every launch.
  updateAppHotkey();
  userPreferences.on('change:' + hotkeyPreference, updateAppHotkey);
});

// Quit when all windows are closed if we're not on Mac.
// On Mac the app will stay active until the user quits explicitly with Cmd+Q.
app.on('window-all-closed', function() {
  if (Environment.isWindows()) {
    app.quit();
  }
});
