var app = require('electron').app;
var childProcess = require('child_process');
var Environment = require('./Environment');
var path = require('path');

// Determined by the installer: https://github.com/atom/grunt-electron-installer#configuring
var BINARY_NAME = 'mixmax.exe';

/**
 * Installs/uninstalls various extensions of the Windows app in response to Squirrel events.
 *
 * @return {Boolean} `true` if the app was started by Squirrel for Windows and is going to quit after
 *   handling the event (so the client should not continue to set up the app), `false` otherwise.
 */
var handleWindowsStartupEvent = function() {
  if (!Environment.isWindows()) {
    return false;
  }

  // For info on events, see https://github.com/atom/grunt-electron-installer#handling-squirrel-events.
  // We must always quit after handling an event.
  var squirrelCommand = process.argv[1];
  switch (squirrelCommand) {
    case '--squirrel-install':
    case '--squirrel-updated':
      // Install desktop shortcut. Future extensions:
      // - Add your .exe to the PATH
      // - Write to the registry for things like file associations and
      //   explorer context menus
      updateShortcut(true /* install */, function(){
        app.quit();
      });

      return true;

    case '--squirrel-uninstall':
      updateShortcut(false /* install */, function() {
        app.quit();
      });

      return true;
    case '--squirrel-obsolete':
      app.quit();

      return true;
  }
};

function updateShortcut(install, done) {
  var updateDotExe = path.resolve(path.dirname(process.execPath), '..', 'update.exe');

  var command = install ? '--createShortcut' : '--removeShortcut';

  childProcess
    .spawn(updateDotExe, [command, BINARY_NAME], { detached: true })
    .on('close', function() {
      done();
    });
}

module.exports = handleWindowsStartupEvent;
