var BrowserWindow = require('electron').BrowserWindow; // Module to create native browser window.
var electronSettings = require('../../electronSettings');
var Environment = require('../../utils/Environment');
var focusWindowOnLaunchFromUrl = require('./focusWindowOnLaunchFromUrl');
var showWindowWhenLoaded = require('./showWindowWhenLoaded');
var path = require('path');
var preventWindowFromBeingClosed = require('./preventWindowFromBeingClosed');
var proxyWindowEvents = require('./proxyWindowEvents');

var initialize = function() {
  if (!module.exports.window) {
    var window = new BrowserWindow(getWindowOptions());

    showWindowWhenLoaded(window);
    // On Mac, prevent the main window from being closed, but rather hide it. 
    if (Environment.isMac()) {
      preventWindowFromBeingClosed(window);
    }
    focusWindowOnLaunchFromUrl(window);
    proxyWindowEvents(window);

    var launchUrl = electronSettings.rootUrl;
    if (electronSettings.launchPath) {
      launchUrl += electronSettings.launchPath;
    }
    window.loadURL(launchUrl);

    // Make the main window available to other modules, and also prevent it from being garbage collected
    // and closed.
    module.exports.window = window;
  }
  return module.exports.window;
};

function getWindowOptions() {
  var options = {
    width: electronSettings.width || 800,
    height: electronSettings.height || 600,
    resizable: true,
    frame: true,
    /**
     * Disable Electron's Node integration so that browser dependencies like `moment` will load themselves
     * like normal i.e. into the window rather than into modules, and also to prevent untrusted client
     * code from having access to the process and file system:
     *  - https://github.com/atom/electron/issues/254
     *  - https://github.com/atom/electron/issues/1753
     */
     webPreferences: {
      nodeIntegration: false,
      // See comments at the top of `preload.js`.
      preload: path.join(__dirname, 'preload.js'),
      // https://app.asana.com/0/19141607276671/77688265943933
      // Despite comments in https://github.com/atom/electron/issues/2076 about this defaulting to
      // `false`, Chrome 47 allows insecure images with only a warning.
      allowDisplayingInsecureContent: true
    },
    // Wait until the window has loaded to show it since we can't set a background color:
    // https://app.asana.com/0/62901882894067/71695986371304
    // Works in tandem with `showWindowWhenLoaded` (above), as well as our patch to `window.open`
    // in the preload script (due to https://github.com/atom/electron/issues/3751)
    show: false
  };

  if (electronSettings.resizable === false){
    options.resizable = false;
  }

  if (electronSettings['title-bar-style']) {
    options['title-bar-style'] = electronSettings['title-bar-style'];
  }

  if (electronSettings.minWidth) {
    options.minWidth = electronSettings.minWidth;
  }

  if (electronSettings.maxWidth) {
    options.maxWidth = electronSettings.maxWidth;
  }

  if (electronSettings.minHeight) {
    options.minHeight = electronSettings.minHeight;
  }

  if (electronSettings.maxHeight) {
    options.maxHeight = electronSettings.maxHeight;
  }

  if (electronSettings.frame === false){
    options.frame = false;
  }

  return options;
}

module.exports = {
  initialize: initialize,
  window: null
};
