var _ = require('underscore');
var acceleratorFormatter = require('electron-accelerator-formatter');
var Environment = require('../../utils/Environment');
var globalShortcut = require('electron').globalShortcut;
var path = require('path');
var preventMainWindowFromBeingShown = require('./preventMainWindowFromBeingShown');
var promoteWindowsTrayItems = require('electron-promote-windows-tray-items');
var shortcutRegistry = require('../../utils/shortcutRegistry');
var Tray = require('electron').Tray;

var DEFAULT_TOOLTIP = 'Compose Mixmax email';
var SHORTCUT_LABEL = 'the menu bar icon';

var MenuBarIcon = function() {};

_.extend(MenuBarIcon.prototype, {
  _appIcon: null,
  _hotkey: null,

  initialize: function(mainWindow) {
    if (this._appIcon) return;

    if (Environment.isMac()) {
      this._appIcon = new Tray(path.join(__dirname, 'images', 'mixmax-menubar-iconTemplate.png'));
      this._appIcon.setPressedImage(path.join(__dirname, 'images', 'mixmax-menubar-icon-reverseTemplate.png'));
    } else {
      // Use the reverse icon as the default; `setPressedImage` is Mac-only.
      this._appIcon = new Tray(path.join(__dirname, 'images', 'mixmax-menubar-icon-reverseTemplate.png'));
    }
    this._updateTooltip();

    var clickHandlers = preventMainWindowFromBeingShown(mainWindow);
    var click = function(source) {
      clickHandlers.preClickHandler();
      mainWindow.webContents.send('open-mixmax-compose', source);
      clickHandlers.postClickHandler();
    };
    var clickFromIcon = _.partial(click, 'menu bar icon');
    this._clickFromHotkey = _.partial(click, 'menu bar hotkey');

    this._appIcon.on('click', clickFromIcon);

    if (Environment.isWindows()) {
      // TODO(jeff): Re-enable this logic once we fix the sometimes exception:
      // https://app.asana.com/0/62901882894067/80937560369263
      // promoteWindowsTrayItems(function(err) {
      //   // TODO(jeff): Sentry.
      //   if (err) throw err;
      // });
    }
  },

  setHotkey: function(hotkey) {
    if (hotkey === this._hotkey) return;

    // Only unregister the previous hotkey if the hotkey actually changes.
    var previousHotkey = this._hotkey;

    // First condition allows deregistration.
    if (!hotkey ||
      (shortcutRegistry.register(hotkey, SHORTCUT_LABEL) && globalShortcut.register(hotkey, this._clickFromHotkey))) {
      this._hotkey = hotkey;
      this._updateTooltip();
      if (previousHotkey) {
        globalShortcut.unregister(previousHotkey);
        shortcutRegistry.unregister(previousHotkey);
      }
      return true;
    } else {
      return false;
    }
  },

  _updateTooltip: function() {
    var tooltip = DEFAULT_TOOLTIP;
    if (this._hotkey) {
      tooltip += ' · ' + acceleratorFormatter(this._hotkey);
    }
    this._appIcon.setToolTip(tooltip);
  },

  // Generated in `initialize`.
  _clickFromHotkey: null
});

module.exports = new MenuBarIcon();
